@@ -4,18 +4,16 @@ use crate::rpc::tmp_config as rpc_config;
 use pyo3::prelude::*;
 use serde::{Deserialize, Serialize};
 use solana_sdk::commitment_config::CommitmentLevel as CommitmentLevelOriginal;
-use solders_macros::{common_methods, richcmp_eq_only};
+use solders_macros::{common_methods, richcmp_eq_only, EnumIntoPy};
+use solders_primitives::{hash::Hash as SolderHash, pubkey::Pubkey, signature::Signature};
 use solders_traits::{
-    impl_display, py_from_bytes_general_via_cbor, pybytes_general_via_cbor, CommonMethods,
-    PyBytesCbor, PyFromBytesCbor, RichcmpEqualityOnly,
+    impl_display, py_from_bytes_general_via_cbor, pybytes_general_via_cbor, RichcmpEqualityOnly,
 };
 
 use crate::{
     account_decoder::{UiAccountEncoding, UiDataSliceConfig},
     commitment_config::CommitmentLevel,
-    hash::Hash as SolderHash,
     transaction_status::{TransactionDetails, UiTransactionEncoding},
-    Pubkey, Signature,
 };
 
 use super::filter::RpcFilterType;
@@ -26,7 +24,7 @@ macro_rules! rpc_config_impls {
         py_from_bytes_general_via_cbor!($ident);
         impl_display!($ident);
         impl RichcmpEqualityOnly for $ident {}
-        impl CommonMethods<'_> for $ident {}
+        solders_traits::common_methods_default!($ident);
         impl From<rpc_config::$ident> for $ident {
             fn from(c: rpc_config::$ident) -> Self {
                 Self(c)
@@ -104,7 +102,7 @@ pyclass_boilerplate_with_default!(
 #[pymethods]
 impl RpcSendTransactionConfig {
     #[new]
-    #[args(skip_preflight = "false")]
+    #[pyo3(signature = (skip_preflight=false, preflight_commitment=None, max_retries=None, min_context_slot=None))]
     pub fn new(
         skip_preflight: bool,
         preflight_commitment: Option<CommitmentLevel>,
@@ -228,7 +226,7 @@ pyclass_boilerplate_with_default!(
 #[pymethods]
 impl RpcSimulateTransactionConfig {
     #[new]
-    #[args(sig_verify = "false", replace_recent_blockhash = "false")]
+    #[pyo3(signature = (sig_verify=false, replace_recent_blockhash=false, commitment=None, accounts=None, min_context_slot=None))]
     fn new(
         sig_verify: bool,
         replace_recent_blockhash: bool,
@@ -875,7 +873,7 @@ impl RpcTransactionLogsFilterMentions {
 
 impl RichcmpEqualityOnly for RpcTransactionLogsFilterMentions {}
 
-#[derive(FromPyObject, Clone, PartialEq, Eq, Serialize, Deserialize, Debug)]
+#[derive(FromPyObject, Clone, PartialEq, Eq, Serialize, Deserialize, Debug, EnumIntoPy)]
 pub enum TransactionLogsFilterWrapper {
     Plain(RpcTransactionLogsFilter),
     Mentions(RpcTransactionLogsFilterMentions),
@@ -917,15 +915,6 @@ impl From<rpc_config::RpcTransactionLogsFilter> for TransactionLogsFilterWrapper
     }
 }
 
-impl IntoPy<PyObject> for TransactionLogsFilterWrapper {
-    fn into_py(self, py: Python<'_>) -> PyObject {
-        match self {
-            Self::Plain(f) => f.into_py(py),
-            Self::Mentions(m) => m.into_py(py),
-        }
-    }
-}
-
 pyclass_boilerplate!(
     /// Configuration object for ``logsSubscribe``.
     ///
@@ -1010,7 +999,7 @@ impl RpcTokenAccountsFilterProgramId {
 
 impl RichcmpEqualityOnly for RpcTokenAccountsFilterProgramId {}
 
-#[derive(FromPyObject, Clone, Debug, PartialEq, Eq, Serialize, Deserialize)]
+#[derive(FromPyObject, Clone, Debug, PartialEq, Eq, Serialize, Deserialize, EnumIntoPy)]
 pub enum RpcTokenAccountsFilterWrapper {
     Mint(RpcTokenAccountsFilterMint),
     ProgramId(RpcTokenAccountsFilterProgramId),
@@ -1038,15 +1027,6 @@ impl From<rpc_config::RpcTokenAccountsFilter> for RpcTokenAccountsFilterWrapper
     }
 }
 
-impl IntoPy<PyObject> for RpcTokenAccountsFilterWrapper {
-    fn into_py(self, py: Python<'_>) -> PyObject {
-        match self {
-            RpcTokenAccountsFilterWrapper::Mint(m) => m.into_py(py),
-            RpcTokenAccountsFilterWrapper::ProgramId(m) => m.into_py(py),
-        }
-    }
-}
-
 pyclass_boilerplate_with_default!(
     /// Configuration object for ``signatureSubscribe``.
     ///
@@ -1131,7 +1111,7 @@ impl RpcBlockSubscribeFilterMentions {
 
 impl RichcmpEqualityOnly for RpcBlockSubscribeFilterMentions {}
 
-#[derive(FromPyObject, Serialize, Deserialize, Clone, Debug, PartialEq, Eq)]
+#[derive(FromPyObject, Serialize, Deserialize, Clone, Debug, PartialEq, Eq, EnumIntoPy)]
 pub enum RpcBlockSubscribeFilterWrapper {
     All(RpcBlockSubscribeFilter),
     MentionsAccountOrProgram(RpcBlockSubscribeFilterMentions),
@@ -1165,15 +1145,6 @@ impl From<rpc_config::RpcBlockSubscribeFilter> for RpcBlockSubscribeFilterWrappe
     }
 }
 
-impl IntoPy<PyObject> for RpcBlockSubscribeFilterWrapper {
-    fn into_py(self, py: Python<'_>) -> PyObject {
-        match self {
-            Self::All(m) => m.into_py(py),
-            Self::MentionsAccountOrProgram(m) => m.into_py(py),
-        }
-    }
-}
-
 pyclass_boilerplate_with_default!(
     /// Configuration object for ``blockSubscribe``.
     ///
